==> haskell-hiedb-0.3.0.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hiedb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hiedb
version:              0.3.0.1
visibility:           public
id:                   hiedb-0.3.0.1-DWRJpBza03I8hws8gkE9b2
key:                  hiedb-0.3.0.1-DWRJpBza03I8hws8gkE9b2
license:              BSD-3-Clause
copyright:            Zubin Duggal
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             Generates a references DB from .hie files
description:
    Tool and library to index and query a collection of `.hie` files

category:             Development
abi:                  9654afc01ea5dfdcb3767f9c19999018
exposed:              True
exposed-modules:
    HieDb HieDb.Create HieDb.Dump HieDb.Html HieDb.Query HieDb.Run
    HieDb.Types HieDb.Utils

import-dirs:          /usr/lib/ghc-8.10.4/site-local/hiedb-0.3.0.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hiedb-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/hiedb-0.3.0.1
hs-libraries:         HShiedb-0.3.0.1-DWRJpBza03I8hws8gkE9b2
depends:
    algebraic-graphs-0.5-hZnuvx6osXC7brjoPkmwR
    ansi-terminal-0.11-LkRk8FVsPUc43vjyLHpLwy array-0.5.4.0
    base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    directory-1.3.6.0 extra-1.7.9-2iz2eeUzuSk6vWcWekkLY3
    filepath-1.4.2.1 ghc-8.10.4
    hie-compat-0.1.0.0-BawUS8x3AaLFtmpIwUJRjn
    lucid-2.9.12.1-CfHlnJfw6lIDYMPmD9SkJw mtl-2.2.2
    optparse-applicative-0.16.1.0-6VVJUvatWXnIV8LvohLAnJ
    sqlite-simple-0.4.18.0-39qYR0LFazb5pdI5uK1vWU text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-hiedb/html/hiedb.haddock
haddock-html:         /usr/share/doc/haskell-hiedb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hiedb-0.3.0.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hiedb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hiedb
version:              0.3.0.1
visibility:           public
id:                   hiedb-0.3.0.1-CcS0PHMZIxeHU8X6lUp9if
key:                  hiedb-0.3.0.1-CcS0PHMZIxeHU8X6lUp9if
license:              BSD-3-Clause
copyright:            Zubin Duggal
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             Generates a references DB from .hie files
description:
    Tool and library to index and query a collection of `.hie` files

category:             Development
abi:                  44b04d471f11989ed3a7618a0575435a
exposed:              True
exposed-modules:
    HieDb HieDb.Create HieDb.Dump HieDb.Html HieDb.Query HieDb.Run
    HieDb.Types HieDb.Utils

import-dirs:          /usr/lib/ghc-8.10.4/site-local/hiedb-0.3.0.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hiedb-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/hiedb-0.3.0.1
hs-libraries:         HShiedb-0.3.0.1-CcS0PHMZIxeHU8X6lUp9if
depends:
    algebraic-graphs-0.5-F9Y8WAkjxxWH9ONbSAA5r5
    ansi-terminal-0.11-B33URfqMvdcAXWIdsUyVZE array-0.5.4.0
    base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    directory-1.3.6.0 extra-1.7.9-FeOLgE4fXkBLbg55bEDq7y
    filepath-1.4.2.1 ghc-8.10.4
    hie-compat-0.1.0.0-BawUS8x3AaLFtmpIwUJRjn
    lucid-2.9.12.1-KP60HIXgd4RF0yHhQhRpNw mtl-2.2.2
    optparse-applicative-0.16.1.0-B9DBBvhrbFt7Di04tN5A7U
    sqlite-simple-0.4.18.0-FTkzhkgkFMBFEQHlI2TR9S text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-hiedb/html/hiedb.haddock
haddock-html:         /usr/share/doc/haskell-hiedb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
